==> scantailor_0.9.6.orig.tar.gz: scantailor-0.9.6/translations/crashreporter_untranslated.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>CrashReportDialog</name>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="62"/>
        <source>This file contains the internal state of the program when it crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="68"/>
        <source>Dump file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="98"/>
        <source>Sending ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="126"/>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="149"/>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="207"/>
        <source>Sending failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="212"/>
        <source>Successfully sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="14"/>
        <source>Crash Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="20"/>
        <source>Scan Tailor crashed.  That&apos;s usually caused by errors in the software.  You can help us find and fix this problem by submitting this crash report.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="30"/>
        <source>Information to be sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="63"/>
        <source>If you have additional information, for example you know how to reproduce the crash, please provide it here.
English or Russian please.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="71"/>
        <source>If you are willing to provide further assistance to developers to help fix this problem, please provide your email address.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="81"/>
        <source>Email [optional]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> scantailor_0.9.11.1.orig.tar.gz: scantailor-0.9.11.1/translations/crashreporter_untranslated.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>CrashReportDialog</name>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="71"/>
        <source>This file contains the internal state of the program when it crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="77"/>
        <source>Dump file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="105"/>
        <source>Sending ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="136"/>
        <source>Unexpected response (code %1) from dispatcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="161"/>
        <source>Unexpected response from dispatcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="221"/>
        <source>Unexpected response (code %1) from the receiving side</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="227"/>
        <source>Successfully sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="14"/>
        <source>Crash Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="20"/>
        <source>Scan Tailor crashed.  That&apos;s usually caused by errors in the software.  You can help us find and fix the problem by submitting this crash report.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="30"/>
        <source>Information to be sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="63"/>
        <source>If you have additional information, for example you know how to reproduce the crash, please provide it here.
English or Russian please.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="71"/>
        <source>If you are willing to provide further assistance to developers to help fix this problem, please provide your email address.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="81"/>
        <source>Email [optional]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
